@@ -20,7 +20,10 @@ ConfigEnd
 MODULE-DEFINITION-END
 */
 
-#if (MODULE_MAGIC_NUMBER >= 19980527)
+#if (MODULE_MAGIC_NUMBER >= 19990320)
+#define API_3_0
+#include "ap_compat.h"
+#elif (MODULE_MAGIC_NUMBER >= 19980527)
 #define API_3_0
 #include "compat.h"
 #endif
